
function m=runTests(model0, outfile)


    %recycle model if we have it. If not, re-parse it.
    if ~isstruct(model0)
        % modelFile='$MODEL_FILE';
		modelFile=model0;

        initCobraToolbox;
        changeCobraSolver('glpk', 'LP');

        model0=readCbModel(modelFile);
    end

    sol0=optimizeCbModel(model0);
    maxGrowth=sol0.f;


    growthThreshold = maxGrowth*0.3;
    of=fopen(outfile, 'w');

    allTests={ 'CHECKFN','133','132','131','130','137','136','135','134','139','138','CHECKFP','24','25','26','27','20','21','22','23','28','29','4','8','119','120','121','122','123','124','125','126','127','128','129','59','58','55','54','57','56','51','50','53','52','115','114','117','116','111','110','113','112','82','83','80','81','86','87','84','85','3','7','108','109','102','103','100','101','106','107','104','105','39','38','33','32','31','30','37','36','35','34','CHECKTPYNBC10','60','61','62','63','64','65','66','67','68','69','CHECKTNYNBC10','2','6','99','98','CHECKYNBO','91','90','93','92','95','94','97','96','11','10','13','12','15','14','17','16','19','18','88','89','151','150','152','41','CHECKTP','48','49','46','47','44','45','42','43','40','118','1','5','9','CHECKTN','146','147','144','145','142','143','140','141','148','149','77','76','75','74','73','72','71','70','79','78' };

    for t=allTests
        % prepare the test function to call
		testName=char(strcat('test_',t));
        test=str2func(testName);
        % disp(testName);
        res=test(model0, growthThreshold);
        fprintf(of, '%s,%s\n', char(t), res);
    end

    m=model0;
    return

% END runTests

function t=test_CHECKFN(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    model2=changeRxnBounds(model1, {'r_90_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_133(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_51_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from KabranX
    if ismember(0, ismember({'YALI0C16885g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0C16885g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_132(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_125_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from KabranX
    if ismember(0, ismember({'YALI0C16885g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0C16885g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_131(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on 
    model2=changeRxnBounds(model1, {'r_30_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from KabranX
    if ismember(0, ismember({'YALI0C16885g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0C16885g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_130(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_125_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from HaddoucheX
    if ismember(0, ismember({'YALI0D24431g','YALI0E34793g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0D24431g','YALI0E34793g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_137(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on 
    model2=changeRxnBounds(model1, {'r_30_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from KabranX
    if ismember(0, ismember({'YALI0E02684g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E02684g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_136(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_51_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from KabranX
    if ismember(0, ismember({'YALI0E15708g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E15708g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_135(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_125_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from KabranX
    if ismember(0, ismember({'YALI0E15708g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E15708g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_134(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on 
    model2=changeRxnBounds(model1, {'r_30_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from KabranX
    if ismember(0, ismember({'YALI0E15708g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E15708g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_139(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_51_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from KabranX
    if ismember(0, ismember({'YALI0E02684g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E02684g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_138(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_125_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from KabranX
    if ismember(0, ismember({'YALI0E02684g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E02684g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_CHECKFP(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    model2=changeRxnBounds(model1, {'r_51_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_24(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    %undefined media conditions not allowed
t='NA'; return;
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_25(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    model2=changeRxnBounds(model1, {'r_71_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_26(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    %undefined media conditions not allowed
t='NA'; return;
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_27(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    model2=changeRxnBounds(model1, {'r_89_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_20(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    model2=changeRxnBounds(model1, {'r_54_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_21(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    model2=changeRxnBounds(model1, {'r_7_exchange','r_3_exchange'}, [10 10], {'u','u'});
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_22(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    %undefined media conditions not allowed
t='NA'; return;
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_23(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    model2=changeRxnBounds(model1, {'r_59_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_28(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    model2=changeRxnBounds(model1, {'r_90_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_29(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    %undefined media conditions not allowed
t='NA'; return;
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_4(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    %undefined media conditions not allowed
t='NA'; return;
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_8(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    %undefined media conditions not allowed
t='NA'; return;
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_119(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    model2=changeRxnBounds(model1, {'r_59_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Flores2005
    if ismember(0, ismember({'YALI0C16885g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0C16885g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_120(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on 
    model2=changeRxnBounds(model1, {'r_93_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Flores2005
    if ismember(0, ismember({'YALI0C16885g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0C16885g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_121(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on 
    model2=changeRxnBounds(model1, {'r_96_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Flores2005
    if ismember(0, ismember({'YALI0C16885g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0C16885g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_122(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_51_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Flores2005
    if ismember(0, ismember({'YALI0C24101g','YALI0C16885g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0C24101g','YALI0C16885g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_123(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    model2=changeRxnBounds(model1, {'r_59_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Flores2005
    if ismember(0, ismember({'YALI0C24101g','YALI0C16885g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0C24101g','YALI0C16885g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_124(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on 
    model2=changeRxnBounds(model1, {'r_93_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Flores2005
    if ismember(0, ismember({'YALI0C24101g','YALI0C16885g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0C24101g','YALI0C16885g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_125(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on 
    model2=changeRxnBounds(model1, {'r_96_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Flores2005
    if ismember(0, ismember({'YALI0C24101g','YALI0C16885g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0C24101g','YALI0C16885g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_126(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_2000_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Yamagami2001
    if ismember(0, ismember({'YALI0E19514g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E19514g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_127(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_51_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Yamagami2001
    if ismember(0, ismember({'YALI0E19514g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E19514g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_128(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    model2=changeRxnBounds(model1, {'r_71_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Yamagami2001
    if ismember(0, ismember({'YALI0E19514g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E19514g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_129(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_51_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from HaddoucheX
    if ismember(0, ismember({'YALI0D24431g','YALI0E34793g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0D24431g','YALI0E34793g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_59(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_2003_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0E09405g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E09405g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_58(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_2000_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0E09405g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E09405g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_55(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_2009_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0E14729g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E14729g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_54(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_2003_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0E14729g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E14729g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_57(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_125_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0E09405g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E09405g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_56(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_51_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0E09405g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E09405g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_51(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_51_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0E14729g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E14729g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_50(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_51_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0D27126g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0D27126g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_53(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_2000_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0E14729g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E14729g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_52(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_125_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0E14729g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E14729g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_115(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    model2=changeRxnBounds(model1, {'r_59_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Flores2005
    if ismember(0, ismember({'YALI0C24101g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0C24101g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_114(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_51_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Flores2005
    if ismember(0, ismember({'YALI0C24101g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0C24101g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_117(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on 
    model2=changeRxnBounds(model1, {'r_96_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Flores2005
    if ismember(0, ismember({'YALI0C24101g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0C24101g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_116(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on 
    model2=changeRxnBounds(model1, {'r_93_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Flores2005
    if ismember(0, ismember({'YALI0C24101g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0C24101g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_111(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    model2=changeRxnBounds(model1, {'r_59_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Jardon2008
    if ismember(0, ismember({'YALI0A15972g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0A15972g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_110(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_51_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Jardon2008
    if ismember(0, ismember({'YALI0A15972g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0A15972g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_113(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on 
    model2=changeRxnBounds(model1, {'r_30_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Jardon2008
    if ismember(0, ismember({'YALI0A15972g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0A15972g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_112(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    model2=changeRxnBounds(model1, {'r_71_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Jardon2008
    if ismember(0, ismember({'YALI0A15972g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0A15972g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_82(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_51_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0B13970g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0B13970g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_83(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_2000_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0B13970g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0B13970g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_80(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_2003_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0E34672g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E34672g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_81(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_2009_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0E34672g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E34672g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_86(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_125_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0E06831g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E06831g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_87(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_2000_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0E06831g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E06831g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_84(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_2003_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0B13970g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0B13970g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_85(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_51_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0E06831g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E06831g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_3(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    %undefined media conditions not allowed
t='NA'; return;
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_7(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    model2=changeRxnBounds(model1, {'r_46_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_108(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    %undefined media conditions not allowed
t='NA'; return;
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Tempel2000
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_109(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    model2=changeRxnBounds(model1, {'r_48_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Tempel2000
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_102(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_2009_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0C16885g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0C16885g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_103(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_51_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0E14729g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E14729g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_100(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_2000_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0C16885g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0C16885g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_101(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_2003_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0C16885g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0C16885g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_106(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_2003_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0E14729g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E14729g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_107(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_2009_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0E14729g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E14729g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_104(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_125_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0E14729g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E14729g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_105(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_2000_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0E14729g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E14729g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_39(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    %undefined media conditions not allowed
t='NA'; return;
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_38(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    %undefined media conditions not allowed
t='NA'; return;
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_33(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    %undefined media conditions not allowed
t='NA'; return;
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_32(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    model2=changeRxnBounds(model1, {'r_115_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_31(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    %undefined media conditions not allowed
t='NA'; return;
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_30(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    model2=changeRxnBounds(model1, {'r_106_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_37(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    model2=changeRxnBounds(model1, {'r_117_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_36(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    %undefined media conditions not allowed
t='NA'; return;
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_35(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    model2=changeRxnBounds(model1, {'r_116_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_34(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    %undefined media conditions not allowed
t='NA'; return;
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_CHECKTPYNBC10(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_2000_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_60(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_51_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0D26081g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0D26081g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_61(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_125_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0D26081g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0D26081g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_62(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_2000_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0D26081g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0D26081g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_63(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_2003_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0D26081g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0D26081g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_64(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_2009_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0D26081g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0D26081g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_65(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_51_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0F04095g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0F04095g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_66(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_125_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0F04095g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0F04095g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_67(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_2009_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0F04095g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0F04095g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_68(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_51_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0E09405g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E09405g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_69(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_125_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0E09405g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E09405g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_CHECKTNYNBC10(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_2000_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0E25982g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E25982g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_2(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    model2=changeRxnBounds(model1, {'r_36_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_6(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    model2=changeRxnBounds(model1, {'r_43_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_99(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_125_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0C16885g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0C16885g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_98(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_51_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0C16885g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0C16885g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_CHECKYNBO(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_125_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_91(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_2003_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0F18216g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0F18216g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_90(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_51_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0F18216g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0F18216g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_93(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_51_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0E03058g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E03058g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_92(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_2009_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0F18216g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0F18216g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_95(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_2000_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0E03058g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E03058g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_94(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_125_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0E03058g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E03058g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_97(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_2009_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0E03058g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E03058g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_96(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_2003_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0E03058g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E03058g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_11(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    %undefined media conditions not allowed
t='NA'; return;
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_10(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    model2=changeRxnBounds(model1, {'r_49_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_13(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    %undefined media conditions not allowed
t='NA'; return;
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_12(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    model2=changeRxnBounds(model1, {'r_50_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_15(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    model2=changeRxnBounds(model1, {'r_37_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_14(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    %undefined media conditions not allowed
t='NA'; return;
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_17(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    %undefined media conditions not allowed
t='NA'; return;
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_16(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    model2=changeRxnBounds(model1, {'r_51_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_19(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    model2=changeRxnBounds(model1, {'r_53_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_18(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    %undefined media conditions not allowed
t='NA'; return;
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_88(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_2003_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0E06831g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E06831g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_89(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_2009_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0E06831g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E06831g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_151(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_51_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Cheon2003
    if ismember(0, ismember({'YALI0B07667g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0B07667g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_150(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Jimenez2001
    model2=changeRxnBounds(model1, {'r_51_exchange','r_137_exchange'}, [10 10], {'u','u'});
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Jimenez2001
    if ismember(0, ismember({'YALI0D02629g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0D02629g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_152(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Cheon2003
    model2=changeRxnBounds(model1, {'r_51_exchange','r_108_exchange'}, [10 10], {'u','u'});
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Cheon2003
    if ismember(0, ismember({'YALI0B07667g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0B07667g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_41(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    %undefined media conditions not allowed
t='NA'; return;
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_CHECKTP(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    model2=changeRxnBounds(model1, {'r_51_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_48(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_2003_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0C06347g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0C06347g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_49(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_2009_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0C06347g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0C06347g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_46(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    model2=changeRxnBounds(model1, {'r_164_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_47(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_125_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0C06347g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0C06347g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_44(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    model2=changeRxnBounds(model1, {'r_148_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_45(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    model2=changeRxnBounds(model1, {'r_149_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_42(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    %undefined media conditions not allowed
t='NA'; return;
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_43(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    %undefined media conditions not allowed
t='NA'; return;
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_40(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    %undefined media conditions not allowed
t='NA'; return;
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_118(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_51_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Flores2005
    if ismember(0, ismember({'YALI0C16885g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0C16885g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_1(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    %undefined media conditions not allowed
t='NA'; return;
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_5(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    %undefined media conditions not allowed
t='NA'; return;
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_9(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    model2=changeRxnBounds(model1, {'r_48_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_CHECKTN(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    model2=changeRxnBounds(model1, {'r_90_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from BioloMICS
    model3=model2;
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_146(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_51_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Beopoulos2008
    if ismember(0, ismember({'YALI0E32835g','YALI0F10857g','YALI0D24750g','YALI0E27654g','YALI0C23859g','YALI0E06567g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E32835g','YALI0F10857g','YALI0D24750g','YALI0E27654g','YALI0C23859g','YALI0E06567g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_147(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    model2=changeRxnBounds(model1, {'r_71_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Beopoulos2008
    if ismember(0, ismember({'YALI0E32835g','YALI0F10857g','YALI0D24750g','YALI0E27654g','YALI0C23859g','YALI0E06567g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E32835g','YALI0F10857g','YALI0D24750g','YALI0E27654g','YALI0C23859g','YALI0E06567g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_144(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    model2=changeRxnBounds(model1, {'r_71_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Beopoulos2008
    if ismember(0, ismember({'YALI0B13970g','YALI0E32835g','YALI0F10857g','YALI0D24750g','YALI0E27654g','YALI0C23859g','YALI0E06567g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0B13970g','YALI0E32835g','YALI0F10857g','YALI0D24750g','YALI0E27654g','YALI0C23859g','YALI0E06567g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_145(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_125_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Beopoulos2008
    if ismember(0, ismember({'YALI0B13970g','YALI0E32835g','YALI0F10857g','YALI0D24750g','YALI0E27654g','YALI0C23859g','YALI0E06567g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0B13970g','YALI0E32835g','YALI0F10857g','YALI0D24750g','YALI0E27654g','YALI0C23859g','YALI0E06567g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_142(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_125_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Beopoulos2008
    if ismember(0, ismember({'YALI0B13970g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0B13970g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_143(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_51_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Beopoulos2008
    if ismember(0, ismember({'YALI0B13970g','YALI0E32835g','YALI0F10857g','YALI0D24750g','YALI0E27654g','YALI0C23859g','YALI0E06567g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0B13970g','YALI0E32835g','YALI0F10857g','YALI0D24750g','YALI0E27654g','YALI0C23859g','YALI0E06567g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_140(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_51_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Beopoulos2008
    if ismember(0, ismember({'YALI0B13970g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0B13970g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_141(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on BioloMICS
    model2=changeRxnBounds(model1, {'r_71_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Beopoulos2008
    if ismember(0, ismember({'YALI0B13970g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0B13970g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_148(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_125_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Beopoulos2008
    if ismember(0, ismember({'YALI0E32835g','YALI0F10857g','YALI0D24750g','YALI0E27654g','YALI0C23859g','YALI0E06567g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E32835g','YALI0F10857g','YALI0D24750g','YALI0E27654g','YALI0C23859g','YALI0E06567g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_149(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_51_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Jimenez2001
    if ismember(0, ismember({'YALI0D02629g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0D02629g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_77(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_51_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0E34672g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E34672g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_76(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_2003_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0C21582g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0C21582g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_75(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_2000_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0C21582g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0C21582g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_74(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_125_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0C21582g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0C21582g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_73(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_51_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0C21582g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0C21582g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_72(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_2009_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0E09405g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E09405g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='+';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_71(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_2003_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0E09405g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E09405g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_70(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_2000_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0E09405g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E09405g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_79(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_2000_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0E34672g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E34672g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1


function t=test_78(model0, growthThreshold)

    % change biomass function
    model1=changeObjective(model0, {'r_021_xxx','r_1814'}, 1);
    
	% first, we explicitly close all carbon inputs

	% iIN800 style
	% model1=changeRxnBounds(model1, { 'EX_glyc(e)', 'EX_xylt(e)', 'EX_tre(e)', 'EX_sucr(e)', 'EX_succ(e)', 'EX_inost(e)', 'EX_melib(e)', 'EX_malt(e)', 'EX_srb_L(e)', 'EX_lac_L(e)', 'EX_arab_L(e)', 'EX_abt(e)', 'EX_glyc(e)', 'EX_etoh(e)', 'EX_xyl_D(e)', 'EX_rib_D(e)', 'EX_glc(e)', 'EX_gam6p(e)', 'EX_gal(e)', 'EX_arab_D(e)', 'EX_cit(e)' }, 0, 'b');

	% jamboree style
	% let them export as much as they want, but limit intake (most of them are closed in the model, except D-glucose (r_51_exchange, closed below)
	% carbonSources={ 'r_7_exchange', 'r_36_exchange', 'r_37_exchange', 'r_43_exchange', 'r_46_exchange', 'r_48_exchange', 'r_51_exchange', 'r_53_exchange', 'r_59_exchange', 'r_71_exchange', 'r_90_exchange', 'r_106_exchange', 'r_115_exchange', 'r_116_exchange', 'r_117_exchange', 'r_125_exchange', 'r_149_exchange', 'r_164_exchange'  };
	carbonSources={'r_51_exchange', 'r_2000_exchange','r_2003_exchange','r_2009_exchange'};
	model1=changeRxnBounds(model1, carbonSources, 0, 'u');
	model1=changeRxnBounds(model1, carbonSources, -1000, 'l');


	% open just a bit all aminoacids
	% model1=changeRxnBounds(model1, {'r_88_exchange', 'r_89_exchange', 'r_90_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_95_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_106_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 10, 'u');
	model1=changeRxnBounds(model1, {'r_88_exchange', 'r_91_exchange', 'r_92_exchange', 'r_93_exchange', 'r_94_exchange', 'r_96_exchange', 'r_97_exchange', 'r_98_exchange', 'r_99_exchange', 'r_100_exchange', 'r_101_exchange', 'r_102_exchange', 'r_103_exchange', 'r_104_exchange', 'r_105_exchange', 'r_107_exchange', 'r_108_exchange', 'r_109_exchange', 'r_110_exchange'}, 0.45, 'u');

    % change media constraints		
    % based on Thevenieau2007
    model2=changeRxnBounds(model1, {'r_125_exchange'}, [10], 'u');
    
    
    % knockout genes gen1,gen2 (locus1,locus2)
    % based on experiments from Thevenieau2007
    if ismember(0, ismember({'YALI0E34672g'}, model0.genes))
        %loci not in model
        t='NA';
        return;
    end
    model3=deleteModelGenes(model2, {'YALI0E34672g'}  );
    
    % experimental result of the experiment (+/-: growth/no-growth)
    expResult='-';
    
    % re-optimize model
    sol3=optimizeCbModel(model3);

    % growth or no growth?
    if sol3.f > growthThreshold
        simGrowth=1;
    else
        simGrowth=0;
    end

	% disp(sol3.f)
	% disp(growthThreshold)

    stat='';
    if expResult=='+'
        if simGrowth==0
            stat='FN';
        else
            stat='TP';   % OK
        end
    else
        if simGrowth==0
            stat='TN';
        else
            stat='FP';   % OK
        end
    end

    % return
    t=stat;

% END test_1

